Updates to doxygen documentation for HIP Event APIs

Change-Id: Ic2e4a5725aebca14ac824da43436aacd0fe0a45c
Αυτή η υποβολή περιλαμβάνεται σε:
Maneesh Gupta
2016-09-16 15:05:48 +05:30
γονέας 8ce8e1de76
υποβολή 3d85cd0ce5
2 αρχεία άλλαξαν με 21 προσθήκες και 26 διαγραφές
-14
Προβολή Αρχείου
@@ -48,9 +48,6 @@ hipError_t ihipEventCreate(hipEvent_t* event, unsigned flags)
return e;
}
/**
* @warning : flags must be 0.
*/
hipError_t hipEventCreateWithFlags(hipEvent_t* event, unsigned flags)
{
HIP_INIT_API(event, flags);
@@ -58,7 +55,6 @@ hipError_t hipEventCreateWithFlags(hipEvent_t* event, unsigned flags)
return ihipLogStatus(ihipEventCreate(event, flags));
}
hipError_t hipEventCreate(hipEvent_t* event)
{
HIP_INIT_API(event);
@@ -66,8 +62,6 @@ hipError_t hipEventCreate(hipEvent_t* event)
return ihipLogStatus(ihipEventCreate(event, 0));
}
//---
hipError_t hipEventRecord(hipEvent_t event, hipStream_t stream)
{
HIP_INIT_API(event, stream);
@@ -100,8 +94,6 @@ hipError_t hipEventRecord(hipEvent_t event, hipStream_t stream)
}
}
//---
hipError_t hipEventDestroy(hipEvent_t event)
{
HIP_INIT_API(event);
@@ -115,8 +107,6 @@ hipError_t hipEventDestroy(hipEvent_t event)
return ihipLogStatus(hipSuccess);
}
//---
hipError_t hipEventSynchronize(hipEvent_t event)
{
HIP_INIT_API(event);
@@ -142,8 +132,6 @@ hipError_t hipEventSynchronize(hipEvent_t event)
}
}
//---
hipError_t hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop)
{
HIP_INIT_API(ms, start, stop);
@@ -187,8 +175,6 @@ hipError_t hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop)
return ihipLogStatus(status);
}
//---
hipError_t hipEventQuery(hipEvent_t event)
{
HIP_INIT_API(event);